<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Show Real-Time Bus Location with Styled UI</title>
    <style>
        body {
            margin: 0;
            font-family: 'Arial', sans-serif;
        }

        #map-container {
            position: relative;
        }

        #map {
            height: 650px;
        }

        #locateButton {
            position: absolute;
            bottom: 10px;
            right: 10px;
            background-color: #3498db;
            color: #fff;
            border: none;
            padding: 10px;
            cursor: pointer;
            border-radius: 5px;
        }

        .popup-content {
            padding: 10px;
        }

        #speed,
        #time {
            font-weight: bold;
        }
    </style>
</head>
<body>

    <div id="map-container">
        <div id="map"></div>
        <button id="locateButton" onclick="centerMapOnBus()">Locate Bus</button>
        <div class="popup-content"></div>
    </div>

    <script async defer
        src="https://maps.googleapis.com/maps/api/js?key=AIzaSyBGVw-TmBC3MI0OMTi7FTypgKfiJsenB28&libraries=places&callback=initMap">
    </script>

    <script>
        var map;
        var busMarker;

        function initMap() {
            map = new google.maps.Map(document.getElementById('map'), {
                center: { lat: 0, lng: 0 },
                zoom: 13
            });

            var busIcon = {
               url: 'https://visionprodesignstech.com/portal-system/images/bus/bus.png',
                size: new google.maps.Size(64, 64), // Adjusted size for better visibility
                origin: new google.maps.Point(0, 0),
                anchor: new google.maps.Point(32, 32) // Set the anchor to the center of the icon
            };

            busMarker = new google.maps.Marker({
                map: map,
                icon: busIcon,
                position: { lat: 0, lng: 0 }
            });

            // Watch user's location and update bus marker
            navigator.geolocation.watchPosition(
                function (position) {
                    var newLatLng = new google.maps.LatLng(position.coords.latitude, position.coords.longitude);
                    busMarker.setPosition(newLatLng);

                    reverseGeocode(newLatLng, function (locationName) {
                        document.querySelector('.popup-content').innerHTML =
                            'Location: ' + locationName +
                            '<br>Speed: <span id="speed">' + (position.coords.speed ? position.coords.speed.toFixed(2) + ' km/h' : 'N/A') + '</span>' +
                            '<br>Time: <span id="time">' + new Date(position.timestamp).toLocaleTimeString() + '</span>';
                    });
                },
                function (error) {
                    console.error("Error getting location: " + error.message);
                },
                { enableHighAccuracy: true, maximumAge: 5000, timeout: 10000 } // Added options for better accuracy and timeout
            );
        }

        function reverseGeocode(latlng, callback) {
            var geocoder = new google.maps.Geocoder();
            geocoder.geocode({ 'location': latlng }, function (results, status) {
                if (status === 'OK') {
                    var locationName = results[0] ? results[0].formatted_address : 'Unknown Location';
                    callback(locationName);
                } else {
                    console.error('Error in reverse geocoding: ' + status);
                    callback('Unknown Location');
                }
            });
        }

        function centerMapOnBus() {
            if (busMarker) {
                map.setCenter(busMarker.getPosition());
            }
        }

        window.onload = function () {
            initMap();
        };
    </script>
</body>
</html>
